"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CelebrationsRepository = void 0;
const entities_1 = require("../entities");
const scrollers_1 = require("../scrollers");
const lodash_1 = __importDefault(require("lodash"));
const utils_1 = require("../utils");
const actionToUrn = (participant) => decodeURIComponent(participant.replace('/feed/update/', ''));
class CelebrationsRepository {
    constructor({ client }) {
        this.client = client;
    }
    getCelebrations({ type = entities_1.CelebrationEnum.WORK_ANNIVERSARY, skip = 0, limit = 10, }) {
        return new scrollers_1.CelebrationScroller({
            type,
            skip,
            limit,
            fetchCelebration: this.fetchCelebrations.bind(this),
        });
    }
    async fetchCelebrations({ type = entities_1.CelebrationEnum.WORK_ANNIVERSARY, skip = 0, limit = 10, }) {
        const response = await this.client.request.celebrations.getCelebrations(type, {
            skip,
            limit,
        });
        const profileIdentities = response.included
            .filter(item => lodash_1.default.get(item, '$type') === 'com.linkedin.voyager.dash.identity.profile.Profile')
            .map(item => item);
        const celebrationIdentities = response.included
            .filter(item => lodash_1.default.get(item, '$type') === 'com.linkedin.voyager.dash.props.PropCard')
            .map(item => item);
        const profileUserIds = celebrationIdentities
            .filter(item => profileIdentities.some(id => id.entityUrn === item.headerImage.attributes[0].detailData['*profilePicture']))
            .filter(item => !item.actions.some(action => action === null || action === void 0 ? void 0 : action.action.confirmationAction))
            .map(item => {
            var _a, _b, _c, _d;
            let predefinedMessage;
            for (const action of item.actions) {
                const messageAction = (_a = action === null || action === void 0 ? void 0 : action.action) === null || _a === void 0 ? void 0 : _a.messageAction;
                if (messageAction === null || messageAction === void 0 ? void 0 : messageAction.prefilledMessage) {
                    predefinedMessage = messageAction.prefilledMessage;
                    break;
                }
            }
            return {
                publishedAt: item === null || item === void 0 ? void 0 : item.publishedAt,
                textDate: (_b = item === null || item === void 0 ? void 0 : item.subHeadline) === null || _b === void 0 ? void 0 : _b.text,
                predefinedMessage,
                publicIdentifier: (0, utils_1.transformToProfileIdentifier)((_c = item === null || item === void 0 ? void 0 : item.headerImage) === null || _c === void 0 ? void 0 : _c.actionTarget),
                profileId: (0, utils_1.transformHeaderImageToProfileId)(item === null || item === void 0 ? void 0 : item.headerImage),
                postUrn: actionToUrn((_d = item === null || item === void 0 ? void 0 : item.cardAction) === null || _d === void 0 ? void 0 : _d.displayAction),
            };
        });
        return lodash_1.default.orderBy(profileUserIds, 'publishedAt', 'desc');
    }
}
exports.CelebrationsRepository = CelebrationsRepository;
//# sourceMappingURL=celebrations.repository.js.map