"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeedRepository = void 0;
const scrollers_1 = require("../scrollers");
const transformer_1 = require("../transformer");
const types_1 = require("../types");
class FeedRepository {
    constructor({ client }) {
        this.client = client;
    }
    getFeed({ skip = 0, limit = 10 }) {
        return new scrollers_1.FeedScroller({
            skip,
            limit,
            fetchFeed: this.fetchFeed.bind(this),
        });
    }
    async fetchFeed({ skip = 0, limit = 10 }) {
        const response = await this.client.request.feed.getFeeds({
            skip,
            limit,
        });
        return (0, transformer_1.transformFeed)(response);
    }
    async addFeedReaction({ threadUrn, reactionType = types_1.FeedReactionType.LIKE, }) {
        await this.client.request.feed.addFeedReaction({
            threadUrn,
            reactionType,
        });
    }
    async removeFeedReaction({ threadUrn }) {
        await this.client.request.feed.removeFeedReaction({
            threadUrn,
        });
    }
    async updateFeedReaction({ threadUrn, reactionType = types_1.FeedReactionType.LIKE, }) {
        await this.client.request.feed.updateFeedReaction({
            threadUrn,
            reactionType,
        });
    }
}
exports.FeedRepository = FeedRepository;
//# sourceMappingURL=feed.repository.js.map