"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NotificationRepository = void 0;
const notification_scroller_1 = require("../scrollers/notification.scroller");
const utils_1 = require("../utils");
const transformNotifications = (response) => {
    const notificationUrns = response.data.elements.map(item => item.notificationCardUrn);
    const notifications = response.included.filter(item => notificationUrns.some(urn => urn === item.entityUrn));
    return notifications.map(notification => {
        var _a;
        return ({
            publishedAt: notification === null || notification === void 0 ? void 0 : notification.publishedAt,
            profileId: (0, utils_1.transformHeaderImageToProfileId)(notification.headerImage),
            publicIdentifier: (0, utils_1.transformToProfileIdentifier)(notification.headerImage.actionTarget),
            headlineText: (_a = notification.headline) === null || _a === void 0 ? void 0 : _a.text,
            $type: 'com.linkedin.voyager.dash.identity.notifications.Card',
        });
    });
};
class NotificationRepository {
    constructor({ client }) {
        this.client = client;
    }
    getAcceptedInvitationNotifications(params) {
        return new notification_scroller_1.NotificationScroller({
            ...params,
            fetchAcceptedInvitationNotifications: this.fetchAcceptedInvitationNotifications.bind(this),
        });
    }
    async fetchAcceptedInvitationNotifications(params) {
        const response = await this.client.request.notification.getAcceptedInvitationNotifications(params);
        return transformNotifications(response);
    }
}
exports.NotificationRepository = NotificationRepository;
//# sourceMappingURL=notification.repository.js.map