"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthRequest = void 0;
const querystring_1 = require("querystring");
const cheerio_1 = require("cheerio");
const config_1 = require("../../config");
class AuthRequest {
    constructor({ request }) {
        this.metadata = {};
        this.request = request;
    }
    getAnonymousAuth() {
        return this.request.get(config_1.authUrl, { fullResponse: true });
    }
    async authenticateUser({ username, password, sessionId, }) {
        const payload = {
            session_key: username,
            session_password: password,
            JSESSIONID: sessionId,
        };
        const response = await this.request.post(config_1.authUrl, (0, querystring_1.stringify)(payload), {
            headers: config_1.authHeaders,
            fullResponse: true,
        });
        this.getMetadata();
        return response;
    }
    async getMetadata() {
        var _a, _b;
        if (((_a = this === null || this === void 0 ? void 0 : this.metadata) === null || _a === void 0 ? void 0 : _a.clientApplicationInstance) || ((_b = this === null || this === void 0 ? void 0 : this.metadata) === null || _b === void 0 ? void 0 : _b.clientPageInstanceId)) {
            return this.metadata;
        }
        const res = await this.request.get('/');
        const $ = (0, cheerio_1.load)(res);
        const clientApplicationInstanceRaw = $('meta[name="applicationInstance"]');
        const clientApplicationInstanceContent = clientApplicationInstanceRaw.attr('content');
        if (clientApplicationInstanceRaw && clientApplicationInstanceContent) {
            const clientApplicationInstance = JSON.parse(clientApplicationInstanceContent);
            this.metadata.clientApplicationInstance = clientApplicationInstance;
        }
        const clientPageInstanceIdRaw = $('meta[name="clientPageInstanceId"]');
        const clientPageInstanceIdContent = clientPageInstanceIdRaw.attr('content');
        if (clientPageInstanceIdRaw) {
            const clientPageInstanceId = clientPageInstanceIdContent;
            this.metadata.clientPageInstanceId = clientPageInstanceId;
        }
        return this.metadata;
    }
}
exports.AuthRequest = AuthRequest;
//# sourceMappingURL=auth.request.js.map