"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeedRequest = void 0;
const types_1 = require("../types");
class FeedRequest {
    constructor({ request }) {
        this.request = request;
    }
    getFeeds({ skip = 0, limit = 100 } = {}) {
        const queryParams = {
            start: skip,
            count: limit,
            moduleKey: 'home-feed%3Adesktop',
            q: 'feed',
            sortOrder: 'RELEVANCE',
        };
        return this.request.get('feed/updatesV2', {
            params: queryParams,
        });
    }
    feedReaction({ threadUrn, action, reactionType = types_1.FeedReactionType.LIKE, }) {
        const body = {
            reactionType,
        };
        if (action) {
            delete body.reactionType;
            body.threadUrn = threadUrn;
        }
        if (action === 'updateReaction') {
            body.newReactionType = reactionType;
        }
        return this.request.post('voyagerSocialDashReactions', body, { params: { threadUrn: encodeURIComponent(threadUrn) } });
    }
    async addFeedReaction({ threadUrn, reactionType = types_1.FeedReactionType.LIKE, }) {
        await this.feedReaction({ threadUrn, reactionType });
    }
    async removeFeedReaction({ threadUrn }) {
        await this.feedReaction({ threadUrn, action: 'deleteReaction' });
    }
    async updateFeedReaction({ threadUrn, reactionType = types_1.FeedReactionType.LIKE, }) {
        await this.feedReaction({ threadUrn, action: 'updateReaction', reactionType });
    }
}
exports.FeedRequest = FeedRequest;
//# sourceMappingURL=feed.request.js.map