"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageRequest = void 0;
class MessageRequest {
    constructor({ request }) {
        this.request = request;
    }
    sendMessage({ profileId, conversationId, text, attachments = [], }) {
        const queryParams = {
            action: 'create',
        };
        const directMessagePayload = {
            keyVersion: 'LEGACY_INBOX',
            conversationCreate: {
                eventCreate: {
                    value: {
                        'com.linkedin.voyager.messaging.create.MessageCreate': {
                            attributedBody: {
                                text,
                                attributes: [],
                            },
                            attachments,
                        },
                    },
                },
                subtype: 'MEMBER_TO_MEMBER',
                recipients: [profileId],
            },
        };
        const conversationPayload = {
            eventCreate: {
                originToken: '54b3a724-59c5-4cf2-adbd-660483010a87',
                value: {
                    'com.linkedin.voyager.messaging.create.MessageCreate': {
                        attributedBody: { text, attributes: [] },
                        attachments,
                    },
                },
            },
            dedupeByClientGeneratedToken: false,
        };
        const conversationUrl = `messaging/conversations/${conversationId}/events`;
        const directMessageUrl = 'messaging/conversations';
        const payload = conversationId ? conversationPayload : directMessagePayload;
        const url = conversationId ? conversationUrl : directMessageUrl;
        return this.request.post(url, payload, { params: queryParams });
    }
    getMessages({ conversationId, createdBefore, }) {
        const queryParams = {
            q: 'syncToken',
            ...(createdBefore && { createdBefore: createdBefore.getTime() }),
        };
        return this.request.get(`messaging/conversations/${conversationId}/events`, {
            params: queryParams,
        });
    }
    async getAttachment({ url }) {
        return this.request.get(url, {
            responseType: 'arraybuffer',
            fullResponse: true,
            maxContentLength: 100000000,
            maxBodyLength: 1000000000,
        });
    }
    async uploadAttachmentMetadata({ filename, fileSize }) {
        const url = '/voyager/api/voyagerVideoDashMediaUploadMetadata';
        const uploadMetadataResponse = await this.request.post(url, {
            fileSize,
            filename,
            mediaUploadType: 'MESSAGING_FILE_ATTACHMENT',
        }, {
            params: { action: 'upload' },
        });
        const { urn, singleUploadUrl: uploadUrl } = uploadMetadataResponse.value;
        return { urn, uploadUrl };
    }
    async uploadAttachment({ file, uploadUrl, fileSize, mimetype, }) {
        return this.request.put(uploadUrl, file, {
            headers: {
                'content-type': mimetype,
                'content-length': fileSize,
            },
        });
    }
}
exports.MessageRequest = MessageRequest;
//# sourceMappingURL=message.request.js.map