"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProfileRequest = void 0;
const utils_1 = require("../utils");
const entities_1 = require("../entities");
class ProfileRequest {
    constructor({ request }) {
        this.request = request;
    }
    getProfile({ publicIdentifier }) {
        const queryParams = {
            q: 'memberIdentity',
            memberIdentity: publicIdentifier,
            decorationId: 'com.linkedin.voyager.dash.deco.identity.profile.FullProfileWithEntities-35',
        };
        return this.request.get('identity/dash/profiles', {
            params: queryParams,
        });
    }
    async getIndividualProfile(id) {
        return this.request.get(`identity/profiles/${id}`);
    }
    getOwnProfile() {
        return this.request.get('me');
    }
    async track(eventBody, eventInfo) {
        const payload = [{ eventBody, eventInfo }];
        await this.request.post('/li/track', JSON.stringify(payload), {
            headers: {
                accept: '*/*',
                'content-type': 'text/plain;charset=UTF-8',
            },
        });
        return true;
    }
    async getProfileNetworkInfo(publicProfileId) {
        return this.request.get(`identity/profiles/${publicProfileId}/networkinfo`, {
            headers: {
                accept: 'application/vnd.linkedin.normalized+json+2.1',
            },
        });
    }
    async viewProfile(publicProfileId, targetProfileMemberUrnId = null, networkDistance = null) {
        var _a, _b;
        const myProfile = await this.getOwnProfile();
        if (!targetProfileMemberUrnId) {
            const profile = await this.getIndividualProfile(publicProfileId);
            const miniProfile = (_a = profile === null || profile === void 0 ? void 0 : profile.included) === null || _a === void 0 ? void 0 : _a.find(r => r.$type === entities_1.MINI_PROFILE_TYPE);
            if (miniProfile === null || miniProfile === void 0 ? void 0 : miniProfile.objectUrn) {
                targetProfileMemberUrnId = (0, utils_1.getIdFromUrn)(miniProfile === null || miniProfile === void 0 ? void 0 : miniProfile.objectUrn);
            }
        }
        if (!networkDistance) {
            const profileNetworkInfo = await this.getProfileNetworkInfo(publicProfileId);
            networkDistance = parseInt(profileNetworkInfo.data.distance.value.split('_')[1], 10);
        }
        const viewerPrivacySetting = 'F';
        const myMemberId = myProfile.data.plainId;
        const currentTimeInSeconds = Date.now();
        const metadata = await this.request.auth.getMetadata();
        const clientApplicationInstance = metadata.clientApplicationInstance;
        const clientPageInstanceId = metadata.clientPageInstanceId;
        const trackingId = (_b = metadata.clientApplicationInstance) === null || _b === void 0 ? void 0 : _b.trackingId;
        const eventBody = {
            viewerPrivacySetting,
            networkDistance: networkDistance,
            vieweeMemberUrn: `urn:li:member:${targetProfileMemberUrnId}`,
            profileTrackingId: clientPageInstanceId,
            entityView: {
                viewType: 'profile-view',
                viewerId: Number(myMemberId),
                targetId: Number(targetProfileMemberUrnId),
            },
            header: {
                pageInstance: {
                    pageUrn: 'urn:li:page:d_flagship3_profile_view_base',
                    trackingId: trackingId,
                },
                time: currentTimeInSeconds,
                version: clientApplicationInstance === null || clientApplicationInstance === void 0 ? void 0 : clientApplicationInstance.version,
                clientApplicationInstance: clientApplicationInstance,
            },
            requestHeader: {
                interfaceLocale: 'en_US',
                pageKey: 'd_flagship3_profile_view_base',
                path: `/in/${targetProfileMemberUrnId}/`,
                referer: 'https://www.linkedin.com/feed/',
            },
        };
        const event = {
            eventBody,
            eventInfo: {
                appId: 'com.linkedin.flagship3.d_web',
                eventName: 'ProfileViewEvent',
                topicName: 'ProfileViewEvent',
            },
        };
        await this.track(event.eventBody, event.eventInfo);
        return true;
    }
}
exports.ProfileRequest = ProfileRequest;
//# sourceMappingURL=profile.request.js.map