"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SalesNavigatorCompanyRequest = void 0;
const config_1 = require("../config");
const utils_1 = require("../utils");
class SalesNavigatorCompanyRequest {
    constructor({ request }) {
        this.request = request;
    }
    getCompany({ companyId }) {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiCompanies/${companyId}?decoration=%28entityUrn%2Cname%2Caccount%28saved%2CnoteCount%2ClistCount%2CcrmStatus%2Cstarred%29%2CpictureInfo%2CcompanyPictureDisplayImage%2Cdescription%2Cindustry%2Clocation%2Cheadquarters%2Cwebsite%2CrevenueRange%2CcrmOpportunities%2CflagshipCompanyUrl%2CemployeeGrowthPercentages%2Cemployees*~fs_salesProfile%28entityUrn%2CfirstName%2ClastName%2CfullName%2CpictureInfo%2CprofilePictureDisplayImage%29%2Cspecialties%2Ctype%2CyearFounded%29`;
        return this.request.get(url);
    }
    searchCompanies({ skip = 0, limit = 25, filters = {}, }) {
        var _a, _b, _c, _d, _e, _f;
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiAccountSearch`;
        const buildFilters = [];
        if ((_a = filters.companySizes) === null || _a === void 0 ? void 0 : _a.length) {
            const companySizes = {
                type: 'COMPANY_HEADCOUNT',
                values: filters.companySizes.map(cs => ({
                    id: cs,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(companySizes);
        }
        if ((_b = filters.industries) === null || _b === void 0 ? void 0 : _b.length) {
            const industry = {
                type: 'INDUSTRY',
                values: filters.industries.map(i => ({
                    id: i,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(industry);
        }
        if ((_c = filters.followers) === null || _c === void 0 ? void 0 : _c.length) {
            const followers = {
                type: 'NUM_OF_FOLLOWERS',
                values: filters.followers.map(f => ({
                    id: f,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(followers);
        }
        if ((_d = filters.bingGeos) === null || _d === void 0 ? void 0 : _d.length) {
            const regions = {
                type: 'REGION',
                values: filters.bingGeos.map(bg => ({
                    id: bg,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(regions);
        }
        if ((_e = filters.jobOpportunities) === null || _e === void 0 ? void 0 : _e.length) {
            const jobOpportunities = {
                type: 'JOB_OPPORTUNITIES',
                values: filters.jobOpportunities.map(jo => ({
                    id: jo,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(jobOpportunities);
        }
        const graphqlFilter = {
            recentSearchParam: {
                doLogHistory: false,
            },
            filters: buildFilters,
            ...(((_f = filters.searchKeywords) === null || _f === void 0 ? void 0 : _f.length) && { keywords: encodeURIComponent(filters.searchKeywords) }),
        };
        const queryParams = {
            q: 'searchQuery',
            start: skip,
            count: limit,
            query: graphqlFilter,
            decorationId: 'com.linkedin.sales.deco.desktop.searchv2.AccountSearchResult-2',
        };
        return this.request.get(url, {
            params: queryParams,
            paramsSerializer: utils_1.graphqlParamSerializer,
        });
    }
}
exports.SalesNavigatorCompanyRequest = SalesNavigatorCompanyRequest;
//# sourceMappingURL=sn-company.request.js.map