"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SalesNavigatorProfileRequest = void 0;
const config_1 = require("../config");
const utils_1 = require("../utils");
const utils_2 = require("../utils");
class SalesNavigatorProfileRequest {
    constructor({ request }) {
        this.request = request;
    }
    getProfile({ profileUrn }) {
        const profileId = (0, utils_1.extractProfileId)(profileUrn);
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiProfiles/(profileId:${profileId},authType:NAME_SEARCH,authToken:x0Hp)`;
        const decorations = [
            'entityUrn',
            'objectUrn',
            'pictureInfo',
            'profilePictureDisplayImage',
            'firstName',
            'lastName',
            'fullName',
            'headline',
            'memberBadges',
            'degree',
            'profileUnlockInfo',
            'location',
            'listCount',
            'industry',
            'numOfConnections',
            'inmailRestriction',
            'savedLead',
            'defaultPosition',
            'contactInfo',
            'summary',
            'crmStatus',
            'pendingInvitation',
            'unlocked',
            'relatedColleagueCompanyId',
            'numOfSharedConnections',
            'showTotalConnectionsPage',
            'blockThirdPartyDataSharing',
            'connectedTime',
            'noteCount',
            'flagshipProfileUrl',
            'fullNamePronunciationAudio',
            'memorialized',
            'fullNamePronunciationAudio',
            'positions*',
            'educations*',
        ];
        const queryParams = {
            decoration: `(${decorations.join(',')})`,
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    searchProfiles({ skip = 0, limit = 25, filters = {}, }) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiLeadSearch`;
        const buildFilters = [];
        if ((_a = filters.currentCompanies) === null || _a === void 0 ? void 0 : _a.length) {
            const currentCompanies = {
                type: 'CURRENT_COMPANY',
                values: filters.currentCompanies.map(cc => cc.id ? { id: cc.id, selectionType: 'INCLUDED' } : { text: cc.text, selectionType: 'INCLUDED' }),
            };
            buildFilters.push(currentCompanies);
        }
        if ((_b = filters.companySizes) === null || _b === void 0 ? void 0 : _b.length) {
            const companySizes = {
                type: 'COMPANY_HEADCOUNT',
                values: filters.companySizes.map(cs => ({
                    id: cs,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(companySizes);
        }
        if ((_c = filters.titles) === null || _c === void 0 ? void 0 : _c.length) {
            const titles = {
                type: 'TITLE',
                values: filters.titles.map(t => t.id ? { id: t.id, text: t.text, selectionType: 'INCLUDED' } : { text: t.text, selectionType: 'INCLUDED' }),
                selectedSubFilter: 'CURRENT',
            };
            buildFilters.push(titles);
        }
        if ((_d = filters.seniorityLevels) === null || _d === void 0 ? void 0 : _d.length) {
            const seniorityLevels = {
                type: 'SENIORITY_LEVEL',
                values: filters.seniorityLevels.map(sl => ({
                    id: sl,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(seniorityLevels);
        }
        if ((_e = filters.industries) === null || _e === void 0 ? void 0 : _e.length) {
            const industry = {
                type: 'INDUSTRY',
                values: filters.industries.map(i => ({
                    id: i,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(industry);
        }
        if ((_f = filters.yearsOfExperiences) === null || _f === void 0 ? void 0 : _f.length) {
            const yearsOfExperience = {
                type: 'YEARS_OF_EXPERIENCE',
                values: filters.yearsOfExperiences.map(ye => ({
                    id: ye,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(yearsOfExperience);
        }
        if ((_g = filters.bingGeos) === null || _g === void 0 ? void 0 : _g.length) {
            const regions = {
                type: 'REGION',
                values: filters.bingGeos.map(bg => ({
                    id: bg,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(regions);
        }
        if ((_h = filters.relationships) === null || _h === void 0 ? void 0 : _h.length) {
            const relationships = {
                type: 'RELATIONSHIP',
                values: filters.relationships.map(rs => ({
                    id: rs,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(relationships);
        }
        if ((_j = filters.functions) === null || _j === void 0 ? void 0 : _j.length) {
            const functions = {
                type: 'FUNCTION',
                values: filters.functions.map(f => ({
                    id: f,
                    selectionType: 'INCLUDED',
                })),
            };
            buildFilters.push(functions);
        }
        const graphqlFilter = {
            recentSearchParam: {
                doLogHistory: false,
            },
            filters: buildFilters,
            ...(((_k = filters.searchKeywords) === null || _k === void 0 ? void 0 : _k.length) && { keywords: encodeURIComponent(filters.searchKeywords) }),
        };
        const queryParams = {
            q: 'searchQuery',
            start: skip,
            count: limit,
            query: graphqlFilter,
            decorationId: 'com.linkedin.sales.deco.desktop.searchv2.LeadSearchResult-9',
        };
        return this.request.get(url, {
            params: queryParams,
            paramsSerializer: utils_2.graphqlParamSerializer,
        });
    }
}
exports.SalesNavigatorProfileRequest = SalesNavigatorProfileRequest;
//# sourceMappingURL=sn-profile.request.js.map