"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SalesNavigatorTypeaheadRequest = void 0;
const config_1 = require("../config");
const types_1 = require("../types");
class SalesNavigatorTypeaheadRequest {
    constructor({ request }) {
        this.request = request;
    }
    getLocations({ skip = 0, limit = 25, query }) {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiFacetTypeahead`;
        const queryParams = {
            q: 'query',
            type: 'BING_GEO',
            start: skip,
            count: limit,
            ...(query ? { query } : {}),
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    getJobTitles({ skip = 0, limit = 25, query }) {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiFacetTypeahead`;
        const queryParams = {
            q: 'query',
            type: 'TITLE',
            start: skip,
            count: limit,
            ...(query ? { query } : {}),
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    getIndustries() {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiFacetTypeahead`;
        const queryParams = {
            q: 'query',
            type: 'INDUSTRY',
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    getSeniorityLevels() {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiFacetTypeahead`;
        const queryParams = {
            q: 'query',
            type: 'SENIORITY',
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    getRoleFunctions() {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiFacetTypeahead`;
        const queryParams = {
            q: 'query',
            type: 'FUNCTION',
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    getCompanySizes() {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiFacetTypeahead`;
        const queryParams = {
            q: 'query',
            type: 'COMPANY_SIZE',
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    getCompanies({ skip = 0, limit = 25, query }) {
        const url = `${config_1.linkedinSalesNavigatorUrl}/salesApiFacetTypeahead`;
        const queryParams = {
            q: 'query',
            type: 'COMPANY',
            start: skip,
            count: limit,
            ...(query ? { query } : {}),
        };
        return this.request.get(url, {
            params: queryParams,
        });
    }
    getRelationshipTypes() {
        const relationshipTypes = [
            {
                id: types_1.RELATIONSHIP_TYPES.FIRST_DEGREE,
                displayValue: '1st Degree Connections',
            },
            {
                id: types_1.RELATIONSHIP_TYPES.SECOND_DEGREE,
                displayValue: '2nd Degree Connections',
            },
            {
                id: types_1.RELATIONSHIP_TYPES.THIRD_DEGREE,
                displayValue: '3rd Degree+ Connections',
            },
            {
                id: types_1.RELATIONSHIP_TYPES.GROUP_MEMBERS,
                displayValue: 'Group Members',
            },
        ];
        return this.createTypeaheadResponse(relationshipTypes);
    }
    getSpotlights() {
        const spotlights = [
            {
                id: types_1.SPOTLIGHTS.RECENT_POSITION_CHANGE,
                displayValue: 'Changed jobs in the past 90 days',
            },
            {
                id: types_1.SPOTLIGHTS.TEAMLINK_INTRO,
                displayValue: 'Leads with TeamLink intro',
            },
            {
                id: types_1.SPOTLIGHTS.MENTIONED_IN_THE_NEWS,
                displayValue: 'Mentioned in the news in the past 30 days',
            },
            {
                id: types_1.SPOTLIGHTS.RECENTLY_POSTED_ON_LINKEDIN,
                displayValue: 'Posted on LinkedIn in the past 30 days',
            },
            {
                id: types_1.SPOTLIGHTS.COMMONALITIES,
                displayValue: 'Shared experiences with you',
            },
            {
                id: types_1.SPOTLIGHTS.COMPANY_FOLLOW,
                displayValue: 'Leads that follow your company on LinkedIn',
            },
        ];
        return this.createTypeaheadResponse(spotlights);
    }
    getProfileLanguages() {
        const profileLanguages = types_1.LANGUAGES.map(x => ({
            id: x.id,
            displayValue: x.name,
        }));
        return this.createTypeaheadResponse(profileLanguages);
    }
    getYearsOfExperience() {
        const yearsOfExperience = [
            {
                id: '1',
                displayValue: 'Less than 1 year',
            },
            {
                id: '2',
                displayValue: '1-2 years',
            },
            {
                id: '3',
                displayValue: '3-5 years',
            },
            {
                id: '4',
                displayValue: '6-10 years',
            },
            {
                id: '5',
                displayValue: 'More than 10 years',
            },
        ];
        return this.createTypeaheadResponse(yearsOfExperience);
    }
    createTypeaheadResponse(elements) {
        return {
            elements,
            paging: {
                count: 10,
                start: 0,
                links: [],
            },
        };
    }
}
exports.SalesNavigatorTypeaheadRequest = SalesNavigatorTypeaheadRequest;
//# sourceMappingURL=sn-typeahead.request.js.map